# Orn: An opinionated python monorepo build tool

## Goals

- [ ] Build packages to sdist and wheels
- [ ] Single version across all sub packages
- [ ] Dependencies from one package to another
- [ ] Support for custom repositories, not just pypi
- [ ] "Smart" Test Suite that only runs tests in changed packages
